<?php
/**
 * inspirelite functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package inspirelite
 */
if ( ! function_exists( 'inspirelite_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function inspirelite_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on inspirelite, use a find and replace
		 * to change 'inspirelite' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'inspirelite', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */

		add_editor_style( 'css/custom-editor-style.css' );
		/* post-thumbnail */
		add_theme_support( 'post-thumbnails' );

		the_post_thumbnail('thumbnail');       // Thumbnail (default 150px x 150px max)
		the_post_thumbnail('medium');          // Medium resolution (default 300px x 300px max)
		the_post_thumbnail('large');           // Large resolution (default 640px x 640px max)
		the_post_thumbnail('full');            // Original image resolution (unmodified)
		
		/* post-format */
		add_theme_support('post-formats', array('aside','image','gallery','video','quote','audio'));
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'inspirelite' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'inspirelite_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'inspirelite_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function inspirelite_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'inspirelite_content_width', 640 );
}
add_action( 'after_setup_theme', 'inspirelite_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function inspirelite_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'inspirelite' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'inspirelite' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'inspirelite_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function inspirelite_scripts() {

	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), '3.3.7', 'all' );
	$query_args = array(
		'family' => 'Roboto:100,100i,300,300i,400,400i,500i,700,700i,900,900i',
		);

	wp_enqueue_style('font-awesome', get_template_directory_uri(). '/css/font-awesome.min.css',array(), '4.7.0','all');
	wp_enqueue_style( 'inspirelite-google-fonts', add_query_arg( $query_args, "//fonts.googleapis.com/css" ) );
	wp_enqueue_style( 'inspirelite-style', get_stylesheet_uri() );
	wp_enqueue_script('bootstrapjs', get_template_directory_uri(). '/js/bootstrap.min.js',array('jquery'),'3.3.7',true);
	wp_enqueue_script( 'jquery-menumaker', get_template_directory_uri() . '/js/menumaker.js', array('jquery'), '', true );
	wp_enqueue_script( 'inspirelite-custom', get_template_directory_uri() . '/js/custom.js', array('jquery'), '20151228', true );

	wp_enqueue_script( 'inspirelite-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array('jquery'), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'inspirelite_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

//remove_filter( 'the_content', 'wpautop' );
//remove_filter( 'the_excerpt', 'wpautop' );

if ( ! function_exists( 'inspirelite_post_thumbnail' ) ) :
function inspirelite_post_thumbnail() {
		// Must be inside a loop.			 
				if ( has_post_thumbnail() ) { ?>
				 <div class="post-img">  
			<a href="<?php echo get_permalink() ?>" class="">
			 <?php the_post_thumbnail('full'); ?> 
			</a></div>
				<?php }
}
endif;

if ( ! function_exists( 'inspirelite_custom_excerpt_length' ) ) :
function inspirelite_custom_excerpt_length() {
	/**
			* Custom Excerpt Length WordPress using wp_trim_excerpt()
			* Use directly in template
			*/
			$content = get_the_content();
			echo wp_trim_words( $content , '30' );
}
endif;			
if ( ! function_exists( 'single_post_pre_next' ) ) :

function single_post_pre_next() {
	 $p = get_adjacent_post(false, '', true); 
	 $n = get_adjacent_post(false, '', false);
	 if(!empty($p) || !empty($n)){
 		echo '<div class="nav-block"><div class="row"><div class="col-lg-12 col-md-12"><div class="prev-next-links"><div class="row">';
		
        // previous post title with link 
        if(!empty($p))
		printf('<div class="col-lg-6 col-md-6 col-sm-6"><div class="prev-link"><a href="%s"><span><i class="fa fa-long-arrow-left"></i> Previous</span> </a><h4><a href="%s" title="%s">%s</a></h4></div></div>', get_permalink($p->ID), get_permalink($p->ID) , $p->post_title , $p->post_title  );
	                
		// next post title with link 
		if(!empty($n))
		printf('<div class="col-lg-6 col-md-6 col-sm-6"><div class="next-link"><a href="%s"><span>Next <i class="fa fa-long-arrow-right"></i> </span></a><h4><a href="%s" title="%s">%s</a></h4></div></div>', get_permalink($n->ID), get_permalink($n->ID), $n->post_title , $n->post_title ); 
				
 		echo '</div></div></div></div></div>';
	 }		
}
endif;
/* pagination */
if ( ! function_exists( 'numeric_posts_nav' ) ) :
function numeric_posts_nav() {
    if( is_singular() )
        return;
    global $wp_query;
    /** Stop execution if there's only 1 page */
    if( $wp_query->max_num_pages <= 1 )
        return;
    $paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
    $max   = intval( $wp_query->max_num_pages );
    /** Add current page to the array */
    if ( $paged >= 1 )
        $links[] = $paged;
    /** Add the pages around the current page to the array */
    if ( $paged >= 3 ) {
        $links[] = $paged - 1;
        $links[] = $paged - 2;
    }
    if ( ( $paged + 2 ) <= $max ) {
        $links[] = $paged + 2;
        $links[] = $paged + 1;
    }
    echo '<div class="st-pagination"><ul class="pagination">' . "\n";
    /** Previous Post Link */
    if ( get_previous_posts_link() )
        printf( '<li>%s</li>' . "\n", get_previous_posts_link() );
    /** Link to first page, plus ellipses if necessary */
    if ( ! in_array( 1, $links ) ) {
        $class = 1 == $paged ? ' class="active"' : '';
        printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );
        if ( ! in_array( 2, $links ) )
            echo '<li></li>';
    }
    /** Link to current page, plus 2 pages in either direction if necessary */
    sort( $links );
    foreach ( (array) $links as $link ) {
        $class = $paged == $link ? ' class="active"' : '';
        printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
    }
    /** Link to last page, plus ellipses if necessary */
    if ( ! in_array( $max, $links ) ) {
        if ( ! in_array( $max - 1, $links ) )
            echo '<li></li>' . "\n";
        $class = $paged == $max ? ' class="active"' : '';
        printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
    }
    /** Next Post Link */
    if ( get_next_posts_link() )
        printf( '<li>%s</li>' . "\n", get_next_posts_link() );
    echo '</ul></div>' . "\n";
}
endif;
/**
*  The Blog post video iframe support browser.
*/
if(!function_exists('inspirelite_video_embed')){
    function inspirelite_video_embed($embed_code){
		$embed_code=str_replace('webkitallowfullscreen','',$embed_code);
		$embed_code=str_replace('mozallowfullscreen','',$embed_code);
		$embed_code=str_replace('frameborder="0"','',$embed_code);
		$embed_code=str_replace('frameborder="no"','',$embed_code);
		$embed_code=str_replace('scrolling="no"','',$embed_code);
		$embed_code=str_replace('&','&amp;',$embed_code);
		return $embed_code;
	}
}

